@@ -29,6 +29,7 @@ use zellij_utils::{
     errors::{ClientContext, ContextType, ErrorInstruction},
     input::{config::Config, options::Options},
     ipc::{ClientAttributes, ClientToServerMsg, ExitReason, ServerToClientMsg},
+    pane_size::Size,
     termwiz::input::InputEvent,
 };
 use zellij_utils::{cli::CliArgs, input::layout::Layout};
@@ -49,6 +50,9 @@ pub(crate) enum ClientInstruction {
     LogError(Vec<String>),
     SwitchSession(ConnectToSession),
     SetSynchronizedOutput(Option<SyncOutput>),
+    UnblockCliPipeInput(String),   // String -> pipe name
+    CliPipeOutput(String, String), // String -> pipe name, String -> output
+    QueryTerminalSize,
 }
 
 impl From<ServerToClientMsg> for ClientInstruction {
@@ -67,6 +71,13 @@ impl From<ServerToClientMsg> for ClientInstruction {
             ServerToClientMsg::SwitchSession(connect_to_session) => {
                 ClientInstruction::SwitchSession(connect_to_session)
             },
+            ServerToClientMsg::UnblockCliPipeInput(pipe_name) => {
+                ClientInstruction::UnblockCliPipeInput(pipe_name)
+            },
+            ServerToClientMsg::CliPipeOutput(pipe_name, output) => {
+                ClientInstruction::CliPipeOutput(pipe_name, output)
+            },
+            ServerToClientMsg::QueryTerminalSize => ClientInstruction::QueryTerminalSize,
         }
     }
 }
@@ -87,6 +98,9 @@ impl From<&ClientInstruction> for ClientContext {
             ClientInstruction::DoneParsingStdinQuery => ClientContext::DoneParsingStdinQuery,
             ClientInstruction::SwitchSession(..) => ClientContext::SwitchSession,
             ClientInstruction::SetSynchronizedOutput(..) => ClientContext::SetSynchronisedOutput,
+            ClientInstruction::UnblockCliPipeInput(..) => ClientContext::UnblockCliPipeInput,
+            ClientInstruction::CliPipeOutput(..) => ClientContext::CliPipeOutput,
+            ClientInstruction::QueryTerminalSize => ClientContext::QueryTerminalSize,
         }
     }
 }
@@ -155,7 +169,12 @@ pub fn start_client(
     tab_position_to_focus: Option<usize>,
     pane_id_to_focus: Option<(u32, bool)>, // (pane_id, is_plugin)
     is_a_reconnect: bool,
+    start_detached_and_exit: bool,
 ) -> Option<ConnectToSession> {
+    if start_detached_and_exit {
+        start_server_detached(os_input, opts, config, config_options, info, layout);
+        return None;
+    }
     info!("Starting Zellij client!");
 
     let mut reconnect_to_session = None;
@@ -232,7 +251,7 @@ pub fn start_client(
                     Box::new(opts),
                     Box::new(config_options.clone()),
                     Box::new(layout.unwrap()),
-                    Some(config.plugins.clone()),
+                    Box::new(config.plugins.clone()),
                 ),
                 ipc_pipe,
             )
@@ -489,6 +508,11 @@ pub fn start_client(
             ClientInstruction::SetSynchronizedOutput(enabled) => {
                 synchronised_output = enabled;
             },
+            ClientInstruction::QueryTerminalSize => {
+                os_input.send_to_server(ClientToServerMsg::TerminalResize(
+                    os_input.get_terminal_size_using_fd(0),
+                ));
+            },
             _ => {},
         }
     }
@@ -523,6 +547,69 @@ pub fn start_client(
     reconnect_to_session
 }
 
+pub fn start_server_detached(
+    mut os_input: Box<dyn ClientOsApi>,
+    opts: CliArgs,
+    config: Config,
+    config_options: Options,
+    info: ClientInfo,
+    layout: Option<Layout>,
+) {
+    envs::set_zellij("0".to_string());
+    config.env.set_vars();
+
+    let palette = config
+        .theme_config(&config_options)
+        .unwrap_or_else(|| os_input.load_palette());
+
+    let client_attributes = ClientAttributes {
+        size: Size { rows: 50, cols: 50 }, // just so size is not 0, it doesn't matter because we
+        // immediately detach
+        style: Style {
+            colors: palette,
+            rounded_corners: config.ui.pane_frames.rounded_corners,
+            hide_session_name: config.ui.pane_frames.hide_session_name,
+        },
+        keybinds: config.keybinds.clone(),
+    };
+
+    let create_ipc_pipe = || -> std::path::PathBuf {
+        let mut sock_dir = ZELLIJ_SOCK_DIR.clone();
+        std::fs::create_dir_all(&sock_dir).unwrap();
+        set_permissions(&sock_dir, 0o700).unwrap();
+        sock_dir.push(envs::get_session_name().unwrap());
+        sock_dir
+    };
+
+    let (first_msg, ipc_pipe) = match info {
+        ClientInfo::New(name) | ClientInfo::Resurrect(name, _) => {
+            envs::set_session_name(name.clone());
+            os_input.update_session_name(name);
+            let ipc_pipe = create_ipc_pipe();
+
+            spawn_server(&*ipc_pipe, opts.debug).unwrap();
+
+            (
+                ClientToServerMsg::NewClient(
+                    client_attributes,
+                    Box::new(opts),
+                    Box::new(config_options.clone()),
+                    Box::new(layout.unwrap()),
+                    Box::new(config.plugins.clone()),
+                ),
+                ipc_pipe,
+            )
+        },
+        _ => {
+            eprintln!("Session already exists");
+            std::process::exit(1);
+        },
+    };
+
+    os_input.connect_to_server(&*ipc_pipe);
+    os_input.send_to_server(first_msg);
+}
+
 #[cfg(test)]
 #[path = "./unit/stdin_tests.rs"]
 mod stdin_tests;
