@@ -8,6 +8,7 @@ use nix::pty::Winsize;
 use nix::sys::termios;
 use signal_hook::{consts::signal::*, iterator::Signals};
 use std::io::prelude::*;
+use std::io::IsTerminal;
 use std::os::unix::io::RawFd;
 use std::path::Path;
 use std::sync::{Arc, Mutex};
@@ -95,7 +96,14 @@ pub trait ClientOsApi: Send + Sync {
     fn unset_raw_mode(&self, fd: RawFd) -> Result<(), nix::Error>;
     /// Returns the writer that allows writing to standard output.
     fn get_stdout_writer(&self) -> Box<dyn io::Write>;
-    fn get_stdin_reader(&self) -> Box<dyn io::Read>;
+    /// Returns a BufReader that allows to read from STDIN line by line, also locks STDIN
+    fn get_stdin_reader(&self) -> Box<dyn io::BufRead>;
+    fn stdin_is_terminal(&self) -> bool {
+        true
+    }
+    fn stdout_is_terminal(&self) -> bool {
+        true
+    }
     fn update_session_name(&mut self, new_session_name: String);
     /// Returns the raw contents of standard input.
     fn read_from_stdin(&mut self) -> Result<Vec<u8>, &'static str>;
@@ -186,9 +194,20 @@ impl ClientOsApi for ClientOsInputOutput {
         let stdout = ::std::io::stdout();
         Box::new(stdout)
     }
-    fn get_stdin_reader(&self) -> Box<dyn io::Read> {
+
+    fn get_stdin_reader(&self) -> Box<dyn io::BufRead> {
         let stdin = ::std::io::stdin();
-        Box::new(stdin)
+        Box::new(stdin.lock())
+    }
+
+    fn stdin_is_terminal(&self) -> bool {
+        let stdin = ::std::io::stdin();
+        stdin.is_terminal()
+    }
+
+    fn stdout_is_terminal(&self) -> bool {
+        let stdout = ::std::io::stdout();
+        stdout.is_terminal()
     }
 
     fn send_to_server(&self, msg: ClientToServerMsg) {
@@ -298,8 +317,8 @@ impl Clone for Box<dyn ClientOsApi> {
 }
 
 pub fn get_client_os_input() -> Result<ClientOsInputOutput, nix::Error> {
-    let current_termios = termios::tcgetattr(0)?;
-    let orig_termios = Some(Arc::new(Mutex::new(current_termios)));
+    let current_termios = termios::tcgetattr(0).ok();
+    let orig_termios = current_termios.map(|termios| Arc::new(Mutex::new(termios)));
     let reading_from_stdin = Arc::new(Mutex::new(None));
     Ok(ClientOsInputOutput {
         orig_termios,
