@@ -52,6 +52,7 @@ macro_rules! get_or_create_grid {
                 $self.style.clone(),
                 $self.debug,
                 $self.arrow_fonts,
+                $self.styled_underlines,
             );
             grid.hide_cursor();
             grid
@@ -88,6 +89,7 @@ pub(crate) struct PluginPane {
     requesting_permissions: Option<PluginPermission>,
     debug: bool,
     arrow_fonts: bool,
+    styled_underlines: bool,
 }
 
 impl PluginPane {
@@ -107,6 +109,7 @@ impl PluginPane {
         invoked_with: Option<Run>,
         debug: bool,
         arrow_fonts: bool,
+        styled_underlines: bool,
     ) -> Self {
         let loading_indication = LoadingIndication::new(title.clone()).with_colors(style.colors);
         let initial_loading_message = loading_indication.to_string();
@@ -139,6 +142,7 @@ impl PluginPane {
             requesting_permissions: None,
             debug,
             arrow_fonts,
+            styled_underlines,
         };
         for client_id in currently_connected_clients {
             plugin.handle_plugin_bytes(client_id, initial_loading_message.as_bytes().to_vec());
