@@ -38,6 +38,7 @@ pub fn scrolling_inside_a_pane() {
     let terminal_emulator_color_codes = Rc::new(RefCell::new(HashMap::new()));
     let debug = false;
     let arrow_fonts = true;
+    let styled_underlines = true;
     let mut terminal_pane = TerminalPane::new(
         pid,
         fake_win_size,
@@ -53,6 +54,7 @@ pub fn scrolling_inside_a_pane() {
         None,
         debug,
         arrow_fonts,
+        styled_underlines,
     ); // 0 is the pane index
     let mut text_to_fill_pane = String::new();
     for i in 0..30 {
@@ -84,6 +86,7 @@ pub fn sixel_image_inside_terminal_pane() {
     })));
     let debug = false;
     let arrow_fonts = true;
+    let styled_underlines = true;
     let mut terminal_pane = TerminalPane::new(
         pid,
         fake_win_size,
@@ -99,6 +102,7 @@ pub fn sixel_image_inside_terminal_pane() {
         None,
         debug,
         arrow_fonts,
+        styled_underlines,
     ); // 0 is the pane index
     let sixel_image_bytes = "\u{1b}Pq
         #0;2;0;0;0#1;2;100;100;0#2;2;0;100;0
@@ -130,6 +134,7 @@ pub fn partial_sixel_image_inside_terminal_pane() {
     })));
     let debug = false;
     let arrow_fonts = true;
+    let styled_underlines = true;
     let mut terminal_pane = TerminalPane::new(
         pid,
         fake_win_size,
@@ -145,6 +150,7 @@ pub fn partial_sixel_image_inside_terminal_pane() {
         None,
         debug,
         arrow_fonts,
+        styled_underlines,
     ); // 0 is the pane index
     let pane_content = read_fixture("sixel-image-500px.six");
     terminal_pane.handle_pty_bytes(pane_content);
@@ -170,6 +176,7 @@ pub fn overflowing_sixel_image_inside_terminal_pane() {
     })));
     let debug = false;
     let arrow_fonts = true;
+    let styled_underlines = true;
     let mut terminal_pane = TerminalPane::new(
         pid,
         fake_win_size,
@@ -185,6 +192,7 @@ pub fn overflowing_sixel_image_inside_terminal_pane() {
         None,
         debug,
         arrow_fonts,
+        styled_underlines,
     ); // 0 is the pane index
     let pane_content = read_fixture("sixel-image-500px.six");
     terminal_pane.handle_pty_bytes(pane_content);
@@ -209,6 +217,7 @@ pub fn scrolling_through_a_sixel_image() {
     })));
     let debug = false;
     let arrow_fonts = true;
+    let styled_underlines = true;
     let mut terminal_pane = TerminalPane::new(
         pid,
         fake_win_size,
@@ -224,6 +233,7 @@ pub fn scrolling_through_a_sixel_image() {
         None,
         debug,
         arrow_fonts,
+        styled_underlines,
     ); // 0 is the pane index
     let mut text_to_fill_pane = String::new();
     for i in 0..30 {
@@ -259,6 +269,7 @@ pub fn multiple_sixel_images_in_pane() {
     })));
     let debug = false;
     let arrow_fonts = true;
+    let styled_underlines = true;
     let mut terminal_pane = TerminalPane::new(
         pid,
         fake_win_size,
@@ -274,6 +285,7 @@ pub fn multiple_sixel_images_in_pane() {
         None,
         debug,
         arrow_fonts,
+        styled_underlines,
     ); // 0 is the pane index
     let mut text_to_fill_pane = String::new();
     for i in 0..5 {
@@ -307,6 +319,7 @@ pub fn resizing_pane_with_sixel_images() {
     })));
     let debug = false;
     let arrow_fonts = true;
+    let styled_underlines = true;
     let mut terminal_pane = TerminalPane::new(
         pid,
         fake_win_size,
@@ -322,6 +335,7 @@ pub fn resizing_pane_with_sixel_images() {
         None,
         debug,
         arrow_fonts,
+        styled_underlines,
     ); // 0 is the pane index
     let mut text_to_fill_pane = String::new();
     for i in 0..5 {
@@ -358,6 +372,7 @@ pub fn changing_character_cell_size_with_sixel_images() {
     })));
     let debug = false;
     let arrow_fonts = true;
+    let styled_underlines = true;
     let mut terminal_pane = TerminalPane::new(
         pid,
         fake_win_size,
@@ -373,6 +388,7 @@ pub fn changing_character_cell_size_with_sixel_images() {
         None,
         debug,
         arrow_fonts,
+        styled_underlines,
     ); // 0 is the pane index
     let mut text_to_fill_pane = String::new();
     for i in 0..5 {
@@ -414,6 +430,7 @@ pub fn keep_working_after_corrupted_sixel_image() {
     })));
     let debug = false;
     let arrow_fonts = true;
+    let styled_underlines = true;
     let mut terminal_pane = TerminalPane::new(
         pid,
         fake_win_size,
@@ -429,6 +446,7 @@ pub fn keep_working_after_corrupted_sixel_image() {
         None,
         debug,
         arrow_fonts,
+        styled_underlines,
     ); // 0 is the pane index
 
     let sixel_image_bytes = "\u{1b}PI AM CORRUPTED BWAHAHAq
@@ -468,6 +486,7 @@ pub fn pane_with_frame_position_is_on_frame() {
     })));
     let debug = false;
     let arrow_fonts = true;
+    let styled_underlines = true;
     let mut terminal_pane = TerminalPane::new(
         pid,
         fake_win_size,
@@ -483,6 +502,7 @@ pub fn pane_with_frame_position_is_on_frame() {
         None,
         debug,
         arrow_fonts,
+        styled_underlines,
     ); // 0 is the pane index
 
     terminal_pane.set_content_offset(Offset::frame(1));
@@ -558,6 +578,7 @@ pub fn pane_with_bottom_and_right_borders_position_is_on_frame() {
     })));
     let debug = false;
     let arrow_fonts = true;
+    let styled_underlines = true;
     let mut terminal_pane = TerminalPane::new(
         pid,
         fake_win_size,
@@ -573,6 +594,7 @@ pub fn pane_with_bottom_and_right_borders_position_is_on_frame() {
         None,
         debug,
         arrow_fonts,
+        styled_underlines,
     ); // 0 is the pane index
 
     terminal_pane.set_content_offset(Offset::shift(1, 1));
@@ -648,6 +670,7 @@ pub fn frameless_pane_position_is_on_frame() {
     })));
     let debug = false;
     let arrow_fonts = true;
+    let styled_underlines = true;
     let mut terminal_pane = TerminalPane::new(
         pid,
         fake_win_size,
@@ -663,6 +686,7 @@ pub fn frameless_pane_position_is_on_frame() {
         None,
         debug,
         arrow_fonts,
+        styled_underlines,
     ); // 0 is the pane index
 
     terminal_pane.set_content_offset(Offset::default());
