@@ -105,6 +105,7 @@ pub enum PluginInstruction {
         Option<PathBuf>,
     ),
     DumpLayout(SessionLayoutMetadata, ClientId),
+    ListClientsMetadata(SessionLayoutMetadata, ClientId),
     DumpLayoutToPlugin(SessionLayoutMetadata, PluginId),
     LogLayoutToHd(SessionLayoutMetadata),
     CliPipe {
@@ -173,6 +174,7 @@ impl From<&PluginInstruction> for PluginContext {
                 PluginContext::PermissionRequestResult
             },
             PluginInstruction::DumpLayout(..) => PluginContext::DumpLayout,
+            PluginInstruction::ListClientsMetadata(..) => PluginContext::ListClientsMetadata,
             PluginInstruction::LogLayoutToHd(..) => PluginContext::LogLayoutToHd,
             PluginInstruction::CliPipe { .. } => PluginContext::CliPipe,
             PluginInstruction::CachePluginEvents { .. } => PluginContext::CachePluginEvents,
@@ -190,6 +192,7 @@ pub(crate) fn plugin_thread_main(
     store: Store,
     data_dir: PathBuf,
     mut layout: Box<Layout>,
+    layout_dir: Option<PathBuf>,
     path_to_default_shell: PathBuf,
     zellij_cwd: PathBuf,
     capabilities: PluginCapabilities,
@@ -217,6 +220,7 @@ pub(crate) fn plugin_thread_main(
         client_attributes,
         default_shell,
         layout.clone(),
+        layout_dir,
     );
 
     loop {
@@ -487,6 +491,13 @@ pub(crate) fn plugin_thread_main(
                     client_id,
                 )));
             },
+            PluginInstruction::ListClientsMetadata(mut session_layout_metadata, client_id) => {
+                populate_session_layout_metadata(&mut session_layout_metadata, &wasm_bridge);
+                drop(bus.senders.send_to_pty(PtyInstruction::ListClientsMetadata(
+                    session_layout_metadata,
+                    client_id,
+                )));
+            },
             PluginInstruction::DumpLayoutToPlugin(mut session_layout_metadata, plugin_id) => {
                 populate_session_layout_metadata(&mut session_layout_metadata, &wasm_bridge);
                 match session_serialization::serialize_session_layout(
