@@ -1,6 +1,6 @@
 use crate::plugins::plugin_map::PluginEnv;
 use crate::plugins::zellij_exports::wasi_write_object;
-use wasmer::Instance;
+use wasmer::{Instance, Store};
 
 use zellij_utils::async_channel::{unbounded, Receiver, Sender};
 use zellij_utils::async_std::task;
@@ -14,23 +14,26 @@ pub struct RunningWorker {
     pub name: String,
     pub plugin_config: PluginConfig,
     pub plugin_env: PluginEnv,
+    store: Store,
 }
 
 impl RunningWorker {
     pub fn new(
+        store: Store,
         instance: Instance,
         name: &str,
         plugin_config: PluginConfig,
         plugin_env: PluginEnv,
     ) -> Self {
         RunningWorker {
+            store,
             instance,
             name: name.into(),
             plugin_config,
             plugin_env,
         }
     }
-    pub fn send_message(&self, message: String, payload: String) -> Result<()> {
+    pub fn send_message(&mut self, message: String, payload: String) -> Result<()> {
         let err_context = || format!("Failed to send message to worker");
         let protobuf_message = ProtobufMessage {
             name: message,
@@ -44,7 +47,9 @@ impl RunningWorker {
             .get_function(&self.name)
             .with_context(err_context)?;
         wasi_write_object(&self.plugin_env.wasi_env, &protobuf_bytes).with_context(err_context)?;
-        work_function.call(&[]).with_context(err_context)?;
+        work_function
+            .call(&mut self.store, &[])
+            .with_context(err_context)?;
         Ok(())
     }
 }
@@ -54,7 +59,7 @@ pub enum MessageToWorker {
     Exit,
 }
 
-pub fn plugin_worker(worker: RunningWorker) -> Sender<MessageToWorker> {
+pub fn plugin_worker(mut worker: RunningWorker) -> Sender<MessageToWorker> {
     let (sender, receiver): (Sender<MessageToWorker>, Receiver<MessageToWorker>) = unbounded();
     task::spawn({
         async move {
