@@ -154,6 +154,9 @@ fn host_run_plugin_command(env: FunctionEnvMut<ForeignFunctionEnv>) {
                     PluginCommand::NewTabsWithLayout(raw_layout) => {
                         new_tabs_with_layout(env, &raw_layout)?
                     },
+                    PluginCommand::NewTabsWithLayoutInfo(layout_info) => {
+                        new_tabs_with_layout_info(env, layout_info)?
+                    },
                     PluginCommand::NewTab => new_tab(env),
                     PluginCommand::GoToNextTab => go_to_next_tab(env),
                     PluginCommand::GoToPreviousTab => go_to_previous_tab(env),
@@ -515,11 +518,12 @@ fn open_file_in_place(env: &ForeignFunctionEnv, file_to_open: FileToOpen) {
 fn open_terminal(env: &ForeignFunctionEnv, cwd: PathBuf) {
     let error_msg = || format!("failed to open file in plugin {}", env.plugin_env.name());
     let cwd = env.plugin_env.plugin_cwd.join(cwd);
-    let mut default_shell = env
-        .plugin_env
-        .default_shell
-        .clone()
-        .unwrap_or_else(|| TerminalAction::RunCommand(RunCommand::default()));
+    let mut default_shell = env.plugin_env.default_shell.clone().unwrap_or_else(|| {
+        TerminalAction::RunCommand(RunCommand {
+            command: env.plugin_env.path_to_default_shell.clone(),
+            ..Default::default()
+        })
+    });
     default_shell.change_cwd(cwd);
     let run_command_action: Option<RunCommandAction> = match default_shell {
         TerminalAction::RunCommand(run_command) => Some(run_command.into()),
@@ -536,11 +540,12 @@ fn open_terminal_floating(
 ) {
     let error_msg = || format!("failed to open file in plugin {}", env.plugin_env.name());
     let cwd = env.plugin_env.plugin_cwd.join(cwd);
-    let mut default_shell = env
-        .plugin_env
-        .default_shell
-        .clone()
-        .unwrap_or_else(|| TerminalAction::RunCommand(RunCommand::default()));
+    let mut default_shell = env.plugin_env.default_shell.clone().unwrap_or_else(|| {
+        TerminalAction::RunCommand(RunCommand {
+            command: env.plugin_env.path_to_default_shell.clone(),
+            ..Default::default()
+        })
+    });
     default_shell.change_cwd(cwd);
     let run_command_action: Option<RunCommandAction> = match default_shell {
         TerminalAction::RunCommand(run_command) => Some(run_command.into()),
@@ -553,11 +558,12 @@ fn open_terminal_floating(
 fn open_terminal_in_place(env: &ForeignFunctionEnv, cwd: PathBuf) {
     let error_msg = || format!("failed to open file in plugin {}", env.plugin_env.name());
     let cwd = env.plugin_env.plugin_cwd.join(cwd);
-    let mut default_shell = env
-        .plugin_env
-        .default_shell
-        .clone()
-        .unwrap_or_else(|| TerminalAction::RunCommand(RunCommand::default()));
+    let mut default_shell = env.plugin_env.default_shell.clone().unwrap_or_else(|| {
+        TerminalAction::RunCommand(RunCommand {
+            command: env.plugin_env.path_to_default_shell.clone(),
+            ..Default::default()
+        })
+    });
     default_shell.change_cwd(cwd);
     let run_command_action: Option<RunCommandAction> = match default_shell {
         TerminalAction::RunCommand(run_command) => Some(run_command.into()),
@@ -856,6 +862,19 @@ fn new_tabs_with_layout(env: &ForeignFunctionEnv, raw_layout: &str) -> Result<()
         None,
     )
     .map_err(|e| anyhow!("Failed to parse layout: {:?}", e))?;
+    apply_layout(env, layout);
+    Ok(())
+}
+
+fn new_tabs_with_layout_info(env: &ForeignFunctionEnv, layout_info: LayoutInfo) -> Result<()> {
+    // TODO: cwd
+    let layout = Layout::from_layout_info(&env.plugin_env.layout_dir, layout_info)
+        .map_err(|e| anyhow!("Failed to parse layout: {:?}", e))?;
+    apply_layout(env, layout);
+    Ok(())
+}
+
+fn apply_layout(env: &ForeignFunctionEnv, layout: Layout) {
     let mut tabs_to_open = vec![];
     let tabs = layout.tabs();
     if tabs.is_empty() {
@@ -887,7 +906,6 @@ fn new_tabs_with_layout(env: &ForeignFunctionEnv, raw_layout: &str) -> Result<()
         let error_msg = || format!("Failed to create layout tab");
         apply_action!(action, error_msg, env);
     }
-    Ok(())
 }
 
 fn new_tab(env: &ForeignFunctionEnv) {
@@ -1523,6 +1541,7 @@ fn check_command_permission(
         PluginCommand::SwitchTabTo(..)
         | PluginCommand::SwitchToMode(..)
         | PluginCommand::NewTabsWithLayout(..)
+        | PluginCommand::NewTabsWithLayoutInfo(..)
         | PluginCommand::NewTab
         | PluginCommand::GoToNextTab
         | PluginCommand::GoToPreviousTab
