@@ -16,6 +16,9 @@ pub struct PaneContentsAndUi<'a> {
     focused_clients: Vec<ClientId>,
     multiple_users_exist_in_session: bool,
     z_index: Option<usize>,
+    pane_is_stacked_under: bool,
+    pane_is_stacked_over: bool,
+    should_draw_pane_frames: bool,
 }
 
 impl<'a> PaneContentsAndUi<'a> {
@@ -26,6 +29,9 @@ impl<'a> PaneContentsAndUi<'a> {
         active_panes: &HashMap<ClientId, PaneId>,
         multiple_users_exist_in_session: bool,
         z_index: Option<usize>,
+        pane_is_stacked_under: bool,
+        pane_is_stacked_over: bool,
+        should_draw_pane_frames: bool,
     ) -> Self {
         let mut focused_clients: Vec<ClientId> = active_panes
             .iter()
@@ -40,6 +46,9 @@ impl<'a> PaneContentsAndUi<'a> {
             focused_clients,
             multiple_users_exist_in_session,
             z_index,
+            pane_is_stacked_under,
+            pane_is_stacked_over,
+            should_draw_pane_frames,
         }
     }
     pub fn render_pane_contents_to_multiple_clients(
@@ -194,6 +203,9 @@ impl<'a> PaneContentsAndUi<'a> {
                 style: self.style,
                 color: frame_color,
                 other_cursors_exist_in_session: false,
+                pane_is_stacked_over: self.pane_is_stacked_over,
+                pane_is_stacked_under: self.pane_is_stacked_under,
+                should_draw_pane_frames: self.should_draw_pane_frames,
             }
         } else {
             FrameParams {
@@ -203,6 +215,9 @@ impl<'a> PaneContentsAndUi<'a> {
                 style: self.style,
                 color: frame_color,
                 other_cursors_exist_in_session: self.multiple_users_exist_in_session,
+                pane_is_stacked_over: self.pane_is_stacked_over,
+                pane_is_stacked_under: self.pane_is_stacked_under,
+                should_draw_pane_frames: self.should_draw_pane_frames,
             }
         };
 
@@ -238,7 +253,9 @@ impl<'a> PaneContentsAndUi<'a> {
         session_is_mirrored: bool,
     ) -> Option<PaletteColor> {
         let pane_focused_for_client_id = self.focused_clients.contains(&client_id);
-        if pane_focused_for_client_id {
+        if let Some(override_color) = self.pane.frame_color_override() {
+            Some(override_color)
+        } else if pane_focused_for_client_id {
             match mode {
                 InputMode::Normal | InputMode::Locked => {
                     if session_is_mirrored || !self.multiple_users_exist_in_session {
