@@ -1,6 +1,6 @@
 //! Zellij program-wide constants.
 
-use directories_next::ProjectDirs;
+use directories::ProjectDirs;
 use include_dir::{include_dir, Dir};
 use lazy_static::lazy_static;
 use once_cell::sync::OnceCell;
@@ -20,6 +20,18 @@ pub const SYSTEM_DEFAULT_DATA_DIR_PREFIX: &str = system_default_data_dir();
 
 pub static ZELLIJ_DEFAULT_THEMES: Dir = include_dir!("$CARGO_MANIFEST_DIR/assets/themes");
 
+pub fn session_info_cache_file_name(session_name: &str) -> PathBuf {
+    session_info_folder_for_session(session_name).join("session-metadata.kdl")
+}
+
+pub fn session_layout_cache_file_name(session_name: &str) -> PathBuf {
+    session_info_folder_for_session(session_name).join("session-layout.kdl")
+}
+
+pub fn session_info_folder_for_session(session_name: &str) -> PathBuf {
+    ZELLIJ_SESSION_INFO_CACHE_DIR.join(session_name)
+}
+
 const fn system_default_data_dir() -> &'static str {
     if let Some(data_dir) = std::option_env!("PREFIX") {
         data_dir
@@ -40,6 +52,9 @@ lazy_static! {
         ZELLIJ_CACHE_DIR.join("permissions.kdl");
     pub static ref ZELLIJ_SESSION_INFO_CACHE_DIR: PathBuf =
         ZELLIJ_CACHE_DIR.join(VERSION).join("session_info");
+    pub static ref ZELLIJ_STDIN_CACHE_FILE: PathBuf =
+        ZELLIJ_CACHE_DIR.join(VERSION).join("stdin_cache");
+    pub static ref ZELLIJ_PLUGIN_ARTIFACT_DIR: PathBuf = ZELLIJ_CACHE_DIR.join(VERSION);
 }
 
 pub const FEATURES: &[&str] = &[
@@ -112,6 +127,8 @@ mod unix_only {
     use nix::unistd::Uid;
     use std::env::temp_dir;
 
+    pub const ZELLIJ_SOCK_MAX_LENGTH: usize = 108;
+
     lazy_static! {
         static ref UID: Uid = Uid::current();
         pub static ref ZELLIJ_TMP_DIR: PathBuf = temp_dir().join(format!("zellij-{}", *UID));
