@@ -151,6 +151,10 @@ pub struct Options {
     /// The interval at which to serialize sessions for resurrection (in seconds)
     #[clap(long, value_parser)]
     pub serialization_interval: Option<u64>,
+
+    /// If true, will disable writing session metadata to disk
+    #[clap(long, value_parser)]
+    pub disable_session_metadata: Option<bool>,
 }
 
 #[derive(ArgEnum, Deserialize, Serialize, Debug, Clone, Copy, PartialEq)]
@@ -223,6 +227,9 @@ impl Options {
             .or(self.scrollback_lines_to_serialize);
         let styled_underlines = other.styled_underlines.or(self.styled_underlines);
         let serialization_interval = other.serialization_interval.or(self.serialization_interval);
+        let disable_session_metadata = other
+            .disable_session_metadata
+            .or(self.disable_session_metadata);
 
         Options {
             simplified_ui,
@@ -250,6 +257,7 @@ impl Options {
             scrollback_lines_to_serialize,
             styled_underlines,
             serialization_interval,
+            disable_session_metadata,
         }
     }
 
@@ -302,6 +310,9 @@ impl Options {
             .or_else(|| self.scrollback_lines_to_serialize.clone());
         let styled_underlines = other.styled_underlines.or(self.styled_underlines);
         let serialization_interval = other.serialization_interval.or(self.serialization_interval);
+        let disable_session_metadata = other
+            .disable_session_metadata
+            .or(self.disable_session_metadata);
 
         Options {
             simplified_ui,
@@ -329,6 +340,7 @@ impl Options {
             scrollback_lines_to_serialize,
             styled_underlines,
             serialization_interval,
+            disable_session_metadata,
         }
     }
 
